km3pipe.core.Pump
=================

.. currentmodule:: km3pipe.core

.. autoclass:: Pump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Pump.__init__
      ~Pump.add
      ~Pump.close
      ~Pump.close_file
      ~Pump.configure
      ~Pump.expose
      ~Pump.finish
      ~Pump.get
      ~Pump.next
      ~Pump.open_file
      ~Pump.pre_finish
      ~Pump.process
      ~Pump.require
      ~Pump.rewind_file
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Pump.name
   
   